==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/GetPacketCoreDataPlanePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property packetCoreControlPlaneName The name of the packet core control plane.
 * @property packetCoreDataPlaneName The name of the packet core data plane.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetPacketCoreDataPlanePlainArgs(
    public val packetCoreControlPlaneName: String,
    public val packetCoreDataPlaneName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs.builder()
            .packetCoreControlPlaneName(packetCoreControlPlaneName.let({ args0 -> args0 }))
            .packetCoreDataPlaneName(packetCoreDataPlaneName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPacketCoreDataPlanePlainArgs].
 */
@PulumiTagMarker
public class GetPacketCoreDataPlanePlainArgsBuilder internal constructor() {
    private var packetCoreControlPlaneName: String? = null

    private var packetCoreDataPlaneName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the packet core control plane.
     */
    @JvmName("keeopbktncffwbhs")
    public suspend fun packetCoreControlPlaneName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.packetCoreControlPlaneName = mapped
    }

    /**
     * @param value The name of the packet core data plane.
     */
    @JvmName("urxolvvgvjcvijql")
    public suspend fun packetCoreDataPlaneName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.packetCoreDataPlaneName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mdpkiduywmvoblcm")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPacketCoreDataPlanePlainArgs = GetPacketCoreDataPlanePlainArgs(
        packetCoreControlPlaneName = packetCoreControlPlaneName ?: throw
            PulumiNullFieldException("packetCoreControlPlaneName"),
        packetCoreDataPlaneName = packetCoreDataPlaneName ?: throw
            PulumiNullFieldException("packetCoreDataPlaneName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/GetPacketCoreDataPlanePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property packetCoreControlPlaneName The name of the packet core control plane.
 * @property packetCoreDataPlaneName The name of the packet core data plane.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetPacketCoreDataPlanePlainArgs(
    public val packetCoreControlPlaneName: String,
    public val packetCoreDataPlaneName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.GetPacketCoreDataPlanePlainArgs.builder()
            .packetCoreControlPlaneName(packetCoreControlPlaneName.let({ args0 -> args0 }))
            .packetCoreDataPlaneName(packetCoreDataPlaneName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetPacketCoreDataPlanePlainArgs].
 */
@PulumiTagMarker
public class GetPacketCoreDataPlanePlainArgsBuilder internal constructor() {
    private var packetCoreControlPlaneName: String? = null

    private var packetCoreDataPlaneName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the packet core control plane.
     */
    @JvmName("ahrqdcgbkbktjjyd")
    public suspend fun packetCoreControlPlaneName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.packetCoreControlPlaneName = mapped
    }

    /**
     * @param value The name of the packet core data plane.
     */
    @JvmName("ofpircpdslxhkvqu")
    public suspend fun packetCoreDataPlaneName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.packetCoreDataPlaneName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gjovjlvkftmnploe")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetPacketCoreDataPlanePlainArgs = GetPacketCoreDataPlanePlainArgs(
        packetCoreControlPlaneName = packetCoreControlPlaneName ?: throw
            PulumiNullFieldException("packetCoreControlPlaneName"),
        packetCoreDataPlaneName = packetCoreDataPlaneName ?: throw
            PulumiNullFieldException("packetCoreDataPlaneName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
